==> love_0.9.1.orig.tar.gz: love-0.9.1/src/modules/audio/Source.cpp <==
/**
 * Copyright (c) 2006-2014 LOVE Development Team
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 **/

#include "Source.h"

namespace love
{
namespace audio
{

Source::Source(Type type)
	: type(type)
{
}

Source::~Source()
{
}

bool Source::getConstant(const char *in, Type &out)
{
	return types.find(in, out);
}

bool Source::getConstant(Type in, const char  *&out)
{
	return types.find(in, out);
}

bool Source::getConstant(const char *in, Unit &out)
{
	return units.find(in, out);
}

bool Source::getConstant(Unit in, const char  *&out)
{
	return units.find(in, out);
}

StringMap<Source::Type, Source::TYPE_MAX_ENUM>::Entry Source::typeEntries[] =
{
	{"static", Source::TYPE_STATIC},
	{"stream", Source::TYPE_STREAM},
};

StringMap<Source::Type, Source::TYPE_MAX_ENUM> Source::types(Source::typeEntries, sizeof(Source::typeEntries));

StringMap<Source::Unit, Source::UNIT_MAX_ENUM>::Entry Source::unitEntries[] =
{
	{"seconds", Source::UNIT_SECONDS},
	{"samples", Source::UNIT_SAMPLES},
};

StringMap<Source::Unit, Source::UNIT_MAX_ENUM> Source::units(Source::unitEntries, sizeof(Source::unitEntries));

} // audio
} // love

==> love_11.1.orig.tar.gz: love-11.1/src/modules/audio/Source.cpp <==
/**
 * Copyright (c) 2006-2018 LOVE Development Team
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 **/

#include "Source.h"

namespace love
{
namespace audio
{

love::Type Source::type("Source", &Object::type);

Source::Source(Type sourceType)
	: sourceType(sourceType)
{
}

Source::~Source()
{
}

Source::Type Source::getType() const
{
	return sourceType;
}

bool Source::getConstant(const char *in, Type &out)
{
	return types.find(in, out);
}

bool Source::getConstant(Type in, const char  *&out)
{
	return types.find(in, out);
}

std::vector<std::string> Source::getConstants(Type)
{
	return types.getNames();
}

bool Source::getConstant(const char *in, Unit &out)
{
	return units.find(in, out);
}

bool Source::getConstant(Unit in, const char  *&out)
{
	return units.find(in, out);
}

std::vector<std::string> Source::getConstants(Unit)
{
	return units.getNames();
}

StringMap<Source::Type, Source::TYPE_MAX_ENUM>::Entry Source::typeEntries[] =
{
	{"static", Source::TYPE_STATIC},
	{"stream", Source::TYPE_STREAM},
	{"queue",  Source::TYPE_QUEUE},
};

StringMap<Source::Type, Source::TYPE_MAX_ENUM> Source::types(Source::typeEntries, sizeof(Source::typeEntries));

StringMap<Source::Unit, Source::UNIT_MAX_ENUM>::Entry Source::unitEntries[] =
{
	{"seconds", Source::UNIT_SECONDS},
	{"samples", Source::UNIT_SAMPLES},
};

StringMap<Source::Unit, Source::UNIT_MAX_ENUM> Source::units(Source::unitEntries, sizeof(Source::unitEntries));

} // audio
} // love
